==> symbol-processing-aa-embeddable-2.1.0-1.0.29-sources.jar: org/jetbrains/kotlin/backend/jvm/JvmIrSerializerImpl.kt <==
/*
 * Copyright 2010-2021 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.backend.jvm

import ksp.org.jetbrains.kotlin.backend.common.serialization.DeclarationTable
import ksp.org.jetbrains.kotlin.backend.jvm.lower.getFileClassInfo
import ksp.org.jetbrains.kotlin.backend.jvm.serialization.JvmGlobalDeclarationTable
import ksp.org.jetbrains.kotlin.backend.jvm.serialization.JvmIrSerializerSession
import ksp.org.jetbrains.kotlin.config.CompilerConfiguration
import ksp.org.jetbrains.kotlin.config.JVMConfigurationKeys
import ksp.org.jetbrains.kotlin.config.JvmSerializeIrMode
import ksp.org.jetbrains.kotlin.config.languageVersionSettings
import ksp.org.jetbrains.kotlin.ir.declarations.IrClass
import ksp.org.jetbrains.kotlin.ir.declarations.IrFile
import ksp.org.jetbrains.kotlin.name.FqName

class JvmIrSerializerImpl(private val configuration: CompilerConfiguration) : JvmIrSerializer {

    private val declarationTable = DeclarationTable.Default(JvmGlobalDeclarationTable())

    override fun serializeIrFile(irFile: IrFile): ByteArray? {
        val fileClassFqName = irFile.getFileClassInfo().fileClassFqName
        return makeSerializerSession(fileClassFqName).serializeJvmIrFile(irFile)?.toByteArray()
    }

    override fun serializeTopLevelIrClass(irClass: IrClass): ByteArray? {
        assert(irClass.parent is IrFile)
        val fileClassFqName = (irClass.parent as IrFile).getFileClassInfo().fileClassFqName
        return makeSerializerSession(fileClassFqName).serializeTopLevelClass(irClass)?.toByteArray()
    }

    private fun makeSerializerSession(fileClassFqName: FqName) =
        JvmIrSerializerSession(
            declarationTable,
            configuration.get(JVMConfigurationKeys.SERIALIZE_IR) ?: JvmSerializeIrMode.NONE,
            fileClassFqName,
            configuration.languageVersionSettings,
        )
}

==> symbol-processing-aa-embeddable-2.2.0-2.0.2-sources.jar: org/jetbrains/kotlin/backend/jvm/JvmIrSerializerImpl.kt <==
/*
 * Copyright 2010-2021 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.backend.jvm

import ksp.org.jetbrains.kotlin.backend.common.serialization.DeclarationTable
import ksp.org.jetbrains.kotlin.backend.jvm.lower.getFileClassInfo
import ksp.org.jetbrains.kotlin.backend.jvm.serialization.JvmGlobalDeclarationTable
import ksp.org.jetbrains.kotlin.backend.jvm.serialization.JvmIrSerializerSession
import ksp.org.jetbrains.kotlin.config.CompilerConfiguration
import ksp.org.jetbrains.kotlin.config.JVMConfigurationKeys
import ksp.org.jetbrains.kotlin.config.JvmSerializeIrMode
import ksp.org.jetbrains.kotlin.ir.declarations.IrClass
import ksp.org.jetbrains.kotlin.ir.declarations.IrFile
import ksp.org.jetbrains.kotlin.name.FqName

class JvmIrSerializerImpl(private val configuration: CompilerConfiguration) : JvmIrSerializer {

    private val declarationTable = DeclarationTable.Default(JvmGlobalDeclarationTable())

    override fun serializeIrFile(irFile: IrFile): ByteArray? {
        val fileClassFqName = irFile.getFileClassInfo().fileClassFqName
        return makeSerializerSession(fileClassFqName).serializeJvmIrFile(irFile)?.toByteArray()
    }

    override fun serializeTopLevelIrClass(irClass: IrClass): ByteArray? {
        assert(irClass.parent is IrFile)
        val fileClassFqName = (irClass.parent as IrFile).getFileClassInfo().fileClassFqName
        return makeSerializerSession(fileClassFqName).serializeTopLevelClass(irClass)?.toByteArray()
    }

    private fun makeSerializerSession(fileClassFqName: FqName) =
        JvmIrSerializerSession(
            declarationTable,
            configuration.get(JVMConfigurationKeys.SERIALIZE_IR) ?: JvmSerializeIrMode.NONE,
            fileClassFqName,
            configuration,
        )
}
